addons library
Classes
- Extend this class to create a custom pop action.
- Extend this class to create a custom push action.
- BaseShowSnackBarAction
-
Extend this class to create a custom snack bar action.
Access the ScaffoldMessengerState with
ref.read(snackBarProvider).key.currentState. - Pops the current route off the navigator.
-
Pops all routes until the page of type
Tis visible. - Pops all routes until there is only one left.
- The default push action.
- Builds the PageRoute used to push a page. Extend this class to create a custom transition.
- ShowSnackBarAction
- An action to show a SnackBar.
- SnackBarService
- A service to show SnackBars.
Properties
-
final
-
snackBarProvider
→ Provider<
SnackBarService> -
The Provider for SnackBarService.
final