popUntilRoot static method
Pops all routes until there is only one left.
Implementation
static NavigationPopUntilRootAction popUntilRoot([Object? result]) {
return NavigationPopUntilRootAction._(result);
}
Pops all routes until there is only one left.
static NavigationPopUntilRootAction popUntilRoot([Object? result]) {
return NavigationPopUntilRootAction._(result);
}