popUntilRoot method
Pops all routes until there is only one left.
Implementation
void popUntilRoot([Object? result]) {
_key.currentState?.popUntilWithResult((route) => route.isFirst, result);
}
Pops all routes until there is only one left.
void popUntilRoot([Object? result]) {
_key.currentState?.popUntilWithResult((route) => route.isFirst, result);
}