NavigationTransition class abstract
Builds the PageRoute used to push a page. Extend this class to create a custom transition.
Constructors
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildRoute<
T> (Widget page, RouteSettings settings) → PageRoute< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fade(
{Duration duration = const Duration(milliseconds: 300)}) → NavigationTransition - Fade transition.
Constants
- cupertino → const NavigationTransition
- iOS-style slide transition.
- material → const NavigationTransition
- The platform default (Android-style).
- none → const NavigationTransition
- No animation.