onFirstFrame property
This function is called BEFORE the widget is built for the first time. The view model is available at this point.
Implementation
final void Function(BuildContext context, R vm)? onFirstFrame;
This function is called BEFORE the widget is built for the first time. The view model is available at this point.
final void Function(BuildContext context, R vm)? onFirstFrame;