GlobalRedux class final

The corresponding global redux notifier.

Inheritance
Implemented types

Constructors

GlobalRedux()

Properties

customDebugLabel → String?
Override this to provide a custom debug label.
no setterinherited
debugLabel → String
A label to be used in debug messages and by the RefenaTracingPage.
no setterinherited
dependencies → Set<BaseNotifier>
A collection of notifiers that this notifier depends on.
finalinherited
dependents → Set<BaseNotifier>
A collection of notifiers that depend on this notifier. They will be disposed when this notifier is disposed.
finalinherited
disposeAction → SynchronousReduxAction<ReduxNotifier<void>, void, dynamic>?
no setterinherited
disposed → bool
Whether this notifier is disposed.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initialAction → BaseReduxAction<ReduxNotifier<void>, void, dynamic>?
Override this to provide a custom action that will be dispatched when the notifier is initialized.
no setterinherited
provider → BaseProvider<BaseNotifier<void>, void>?
The provider that created this notifier. This is only available after the initialization.
no setterinherited
redux → Dispatcher<ReduxNotifier<void>, void>
Access the Dispatcher of this notifier.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → void
Gets the current state.
no setterinherited

Methods

describeState(void state) → String
Override this to provide a customized description of the state. This is used by the built-in observers for improved logging.
inherited
dispose() → void
This is called on Ref.dispose. You can override this method to dispose resources.
inherited
external<T2>(ReduxNotifier<T2> notifier) → Dispatcher<ReduxNotifier<T2>, T2>
Creates a Dispatcher for an external notifier.
inherited
init() → void
Initializes the state of the notifier. This method is called only once and as soon as the notifier is accessed the first time.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postInit() → void
Override this to provide a custom post initialization. The initial state is already set at this point.
inherited
toString() → String
A string representation of this object.
inherited
updateShouldNotify(void prev, void next) → bool
Override this if you want to a different kind of equality.
inherited

Operators

operator ==(Object other) → bool
Subclasses should not override this method. It is used internally by dependencies and dependents.
inherited