LabeledReference class abstract interface

An arbitrary object that has a debugLabel property.

Implementers

Properties

debugLabel → String
A label to be used in debug messages and by the RefenaTracingPage.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

custom(String label) → LabeledReference
Creates a custom LabeledReference of any object.