RefenaTracingPage class

Inheritance

Constructors

RefenaTracingPage({Key? key, int slowExecutionThreshold = 500, ErrorParser? errorParser, bool exclude(RefenaEvent event)?, bool include(RefenaEvent event)?, bool showTime = false, String? query, String title = 'Refena Tracing', TracingInputBuilder inputBuilder = const _StateTracingInputBuilder(), Duration loadDelay = const Duration(milliseconds: 300)})
const

Properties

errorParser ErrorParser?
A function to parse an error to a map. See ErrorParser for more details.
final
exclude bool Function(RefenaEvent event)?
If the given function returns true, then the event won't be displayed.
final
hashCode int
The hash code for this object.
no setterinherited
include bool Function(RefenaEvent event)?
If the given function returns true, then the event will be displayed.
final
inputBuilder TracingInputBuilder
The builder to build the input model.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadDelay Duration
The delay before the page is displayed. Used for smooth page transition.
final
query String?
Initial filter query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTime bool
Display a time column by default. This can still be toggled in the UI.
final
slowExecutionThreshold int
Time in milliseconds to consider an event as slow. The execution time will be highlighted in the UI.
final
title String
The title of the page.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RefenaTracingPage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited