TracingInputBuilder class abstract

A configuration for the tracing page.

Constructors

TracingInputBuilder()
const

Properties

hasFinishedEvents bool
If true, then a loading indicator is shown for unfinished actions. If false, then it will be considered true as soon as the first ActionFinishedEvent is received.
no setter
hashCode int
The hash code for this object.
no setterinherited
refreshStream Stream<void>?
If not null, then build will be called on every new stream event.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(Ref ref) Iterable<InputEvent>
Builds the input list either from the state of the app or from a state fetched from the client.
clearEvents(Ref ref) → void
Clears the events.
hasTracingProvider(Ref ref) bool
If false, then an error will be shown if the tracing provider is not available.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited