NavigateAction class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pop(
[Object? result]) → NavigationPopAction - Pops the current route off the navigator.
-
popUntil<
T extends Widget> ([Object? result]) → NavigationPopUntilAction< T> -
Pops all routes until the page of type
Tis visible. -
popUntilRoot(
[Object? result]) → NavigationPopUntilRootAction - Pops all routes until there is only one left.
-
push<
T> (Widget widget, {NavigationTransition? transition}) → NavigationPushAction< T> - Pushes a new route onto the navigator.
-
pushAndRemoveUntil<
T> (Widget widget, {required Type removeUntil, NavigationTransition? transition}) → NavigationPushAndRemoveUntilAction< T> -
Pushes a new route while popping all routes above
removeUntil. -
pushNamed<
T> (String routeName, {Object? arguments}) → NavigationPushNamedAction< T> - Pushes a named route onto the navigator.
-
pushReplacement<
T> (Widget widget, {NavigationTransition? transition}) → NavigationPushReplacementAction< T> - Pushes a new route, replacing the current one.
-
pushRoot<
T> (Widget widget, {NavigationTransition? transition}) → NavigationPushRootAction< T> - Pushes a new route while removing all others.