NavigateAction class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

pop([Object? result]) → NavigationPopAction
Pops the current route off the navigator.
push<T>(Widget widget) → NavigationPushAction<T>
Pushes a new route onto the navigator.
pushNamed<T>(String routeName, {Object? arguments}) → NavigationPushNamedAction<T>
Pushes a named route onto the navigator.