NavigationService class

Constructors

Properties

context → BuildContext
Access the global BuildContext associated with the NavigatorState.
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<NavigatorState>
The GlobalKey to access the NavigatorState.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop([Object? result]) → void
Pops the current route off the navigator.
push<T>(Widget widget) → Future<T?>
Pushes a new route onto the navigator.
pushNamed<T>(String routeName, {Object? arguments}) → Future<T?>
Pushes a named route onto the navigator.
setKey(GlobalKey<NavigatorState> key) → void
Set the GlobalKey to access the NavigatorState. Use this if you already have a GlobalKey for NavigatorState.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited